@@ -3,8 +3,6 @@
 use data_url::mime::Mime;
 use glib::prelude::*;
 use markup5ever::QualName;
-use once_cell::sync::Lazy;
-use std::cell::RefCell;
 use std::collections::hash_map::Entry;
 use std::collections::HashMap;
 use std::fmt;
@@ -13,6 +11,7 @@ use std::io::Cursor;
 use std::rc::Rc;
 use std::str::FromStr;
 use std::sync::Arc;
+use std::{cell::RefCell, sync::OnceLock};
 
 use crate::accept_language::UserLanguage;
 use crate::bbox::BoundingBox;
@@ -32,16 +31,6 @@ use crate::surface_utils::shared_surface::SharedImageSurface;
 use crate::url_resolver::{AllowedUrl, UrlResolver};
 use crate::xml::{xml_load_from_possibly_compressed_stream, Attributes};
 
-static UA_STYLESHEETS: Lazy<Vec<Stylesheet>> = Lazy::new(|| {
-    vec![Stylesheet::from_data(
-        include_str!("ua.css"),
-        &UrlResolver::new(None),
-        Origin::UserAgent,
-        Session::default(),
-    )
-    .expect("could not parse user agent stylesheet for librsvg, there's a bug!")]
-});
-
 /// Identifier of a node
 #[derive(Debug, PartialEq, Clone)]
 pub enum NodeId {
@@ -247,9 +236,21 @@ impl Document {
     /// This uses the default UserAgent stylesheet, the document's internal stylesheets,
     /// plus an extra set of stylesheets supplied by the caller.
     pub fn cascade(&mut self, extra: &[Stylesheet], session: &Session) {
+        let stylesheets = {
+            static UA_STYLESHEETS: OnceLock<Vec<Stylesheet>> = OnceLock::new();
+            UA_STYLESHEETS.get_or_init(|| {
+                vec![Stylesheet::from_data(
+                    include_str!("ua.css"),
+                    &UrlResolver::new(None),
+                    Origin::UserAgent,
+                    Session::default(),
+                )
+                .expect("could not parse user agent stylesheet for librsvg, there's a bug!")]
+            })
+        };
         css::cascade(
             &mut self.tree,
-            &UA_STYLESHEETS,
+            stylesheets,
             &self.stylesheets,
             extra,
             session,
@@ -767,6 +768,7 @@ pub struct AcquiredNodes<'i> {
     document: &'i Document,
     num_elements_acquired: usize,
     node_stack: Rc<RefCell<NodeStack>>,
+    nodes_with_cycles: Vec<Node>,
 }
 
 impl<'i> AcquiredNodes<'i> {
@@ -775,6 +777,7 @@ impl<'i> AcquiredNodes<'i> {
             document,
             num_elements_acquired: 0,
             node_stack: Rc::new(RefCell::new(NodeStack::new())),
+            nodes_with_cycles: Vec::new(),
         }
     }
 
@@ -811,6 +814,10 @@ impl<'i> AcquiredNodes<'i> {
             .lookup_node(node_id)
             .ok_or_else(|| AcquireError::LinkNotFound(node_id.clone()))?;
 
+        if self.nodes_with_cycles.contains(&node) {
+            return Err(AcquireError::CircularReference(node.clone()));
+        }
+
         if node.borrow_element().is_accessed_by_reference() {
             self.acquire_ref(&node)
         } else {
@@ -830,8 +837,11 @@ impl<'i> AcquiredNodes<'i> {
     /// * At the drawing stage, `acquire_ref()` the pattern node that we already had, so that
     /// its child elements that reference other paint servers will be able to detect circular
     /// references to the pattern.
-    pub fn acquire_ref(&self, node: &Node) -> Result<AcquiredNode, AcquireError> {
-        if self.node_stack.borrow().contains(node) {
+    pub fn acquire_ref(&mut self, node: &Node) -> Result<AcquiredNode, AcquireError> {
+        if self.nodes_with_cycles.contains(node) {
+            Err(AcquireError::CircularReference(node.clone()))
+        } else if self.node_stack.borrow().contains(node) {
+            self.nodes_with_cycles.push(node.clone());
             Err(AcquireError::CircularReference(node.clone()))
         } else {
             self.node_stack.borrow_mut().push(node);
