@@ -2,15 +2,14 @@
 
 use float_cmp::approx_eq;
 use glib::translate::*;
-use once_cell::sync::Lazy;
 use pango::ffi::PangoMatrix;
 use pango::prelude::FontMapExt;
 use regex::{Captures, Regex};
-use std::borrow::Cow;
 use std::cell::RefCell;
 use std::convert::TryFrom;
 use std::f64::consts::*;
 use std::rc::Rc;
+use std::{borrow::Cow, sync::OnceLock};
 
 use crate::accept_language::UserLanguage;
 use crate::aspect_ratio::AspectRatio;
@@ -1701,9 +1700,9 @@ impl DrawingCtx {
         let _self_acquired = match acquired_nodes.acquire_ref(node) {
             Ok(n) => n,
 
-            Err(AcquireError::CircularReference(_)) => {
-                rsvg_log!(self.session, "circular reference in element {}", node);
-                return Ok(self.empty_bbox());
+            Err(AcquireError::CircularReference(circular)) => {
+                rsvg_log!(self.session, "circular reference in element {}", circular);
+                return Err(InternalRenderingError::CircularReference(circular));
             }
 
             _ => unreachable!(),
@@ -1712,9 +1711,14 @@ impl DrawingCtx {
         let acquired = match acquired_nodes.acquire(link) {
             Ok(acquired) => acquired,
 
-            Err(AcquireError::CircularReference(node)) => {
-                rsvg_log!(self.session, "circular reference in element {}", node);
-                return Ok(self.empty_bbox());
+            Err(AcquireError::CircularReference(circular)) => {
+                rsvg_log!(
+                    self.session,
+                    "circular reference from {} to element {}",
+                    node,
+                    circular
+                );
+                return Err(InternalRenderingError::CircularReference(circular));
             }
 
             Err(AcquireError::MaxReferencesExceeded) => {
@@ -2192,9 +2196,12 @@ fn setup_cr_for_stroke(cr: &cairo::Context, stroke: &Stroke) {
 
 /// escape quotes and backslashes with backslash
 fn escape_link_target(value: &str) -> Cow<'_, str> {
-    static REGEX: Lazy<Regex> = Lazy::new(|| Regex::new(r"['\\]").unwrap());
+    let regex = {
+        static REGEX: OnceLock<Regex> = OnceLock::new();
+        REGEX.get_or_init(|| Regex::new(r"['\\]").unwrap())
+    };
 
-    REGEX.replace_all(value, |caps: &Captures<'_>| {
+    regex.replace_all(value, |caps: &Captures<'_>| {
         match caps.get(0).unwrap().as_str() {
             "'" => "\\'".to_owned(),
             "\\" => "\\\\".to_owned(),
